About Genshi
============

<!-- badges-start -->

[![ReadTheDocs badge](https://readthedocs.org/projects/genshi/badge/?version=latest&style=for-the-badge)](https://genshi.readthedocs.org/)
[![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/edgewall/genshi/tests.yml?branch=master&style=for-the-badge)](https://github.com/edgewall/genshi/actions/workflows/tests.yml)
[![PyPI - Version](https://img.shields.io/pypi/v/genshi?style=for-the-badge)](https://pypi.org/project/genshi/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/genshi?style=for-the-badge)](https://pypi.org/project/genshi/)
[![PyPI - Implementation](https://img.shields.io/pypi/implementation/genshi?style=for-the-badge)](https://pypi.org/project/genshi/)

<!-- badges-end -->

Genshi is a Python library that provides an integrated set of
components for parsing, generating, and processing HTML, XML or other
textual content for output generation on the web. The major feature is
a template language, which is heavily inspired by Kid.

For more information please see:

- [ReadTheDocs](https://genshi.readthedocs.org/)
- [https://genshi.edgewall.org/](https://genshi.edgewall.org/)
- the documentation in the `doc` directory.

